==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/msk_serverless_cluster/MskServerlessClusterClientAuthentication.java <==
package com.hashicorp.cdktf.providers.aws.msk_serverless_cluster;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:54.810Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.mskServerlessCluster.MskServerlessClusterClientAuthentication")
@software.amazon.jsii.Jsii.Proxy(MskServerlessClusterClientAuthentication.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface MskServerlessClusterClientAuthentication extends software.amazon.jsii.JsiiSerializable {

    /**
     * sasl block.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/msk_serverless_cluster#sasl MskServerlessCluster#sasl}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.msk_serverless_cluster.MskServerlessClusterClientAuthenticationSasl getSasl();

    /**
     * @return a {@link Builder} of {@link MskServerlessClusterClientAuthentication}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MskServerlessClusterClientAuthentication}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<MskServerlessClusterClientAuthentication> {
        com.hashicorp.cdktf.providers.aws.msk_serverless_cluster.MskServerlessClusterClientAuthenticationSasl sasl;

        /**
         * Sets the value of {@link MskServerlessClusterClientAuthentication#getSasl}
         * @param sasl sasl block. This parameter is required.
         *             Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/msk_serverless_cluster#sasl MskServerlessCluster#sasl}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder sasl(com.hashicorp.cdktf.providers.aws.msk_serverless_cluster.MskServerlessClusterClientAuthenticationSasl sasl) {
            this.sasl = sasl;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MskServerlessClusterClientAuthentication}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public MskServerlessClusterClientAuthentication build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link MskServerlessClusterClientAuthentication}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MskServerlessClusterClientAuthentication {
        private final com.hashicorp.cdktf.providers.aws.msk_serverless_cluster.MskServerlessClusterClientAuthenticationSasl sasl;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.sasl = software.amazon.jsii.Kernel.get(this, "sasl", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.msk_serverless_cluster.MskServerlessClusterClientAuthenticationSasl.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.sasl = java.util.Objects.requireNonNull(builder.sasl, "sasl is required");
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.msk_serverless_cluster.MskServerlessClusterClientAuthenticationSasl getSasl() {
            return this.sasl;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("sasl", om.valueToTree(this.getSasl()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.mskServerlessCluster.MskServerlessClusterClientAuthentication"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MskServerlessClusterClientAuthentication.Jsii$Proxy that = (MskServerlessClusterClientAuthentication.Jsii$Proxy) o;

            return this.sasl.equals(that.sasl);
        }

        @Override
        public final int hashCode() {
            int result = this.sasl.hashCode();
            return result;
        }
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/msk_serverless_cluster/MskServerlessClusterClientAuthentication.java <==
package com.hashicorp.cdktf.providers.aws.msk_serverless_cluster;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:10.812Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.mskServerlessCluster.MskServerlessClusterClientAuthentication")
@software.amazon.jsii.Jsii.Proxy(MskServerlessClusterClientAuthentication.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface MskServerlessClusterClientAuthentication extends software.amazon.jsii.JsiiSerializable {

    /**
     * sasl block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/msk_serverless_cluster#sasl MskServerlessCluster#sasl}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.msk_serverless_cluster.MskServerlessClusterClientAuthenticationSasl getSasl();

    /**
     * @return a {@link Builder} of {@link MskServerlessClusterClientAuthentication}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MskServerlessClusterClientAuthentication}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<MskServerlessClusterClientAuthentication> {
        com.hashicorp.cdktf.providers.aws.msk_serverless_cluster.MskServerlessClusterClientAuthenticationSasl sasl;

        /**
         * Sets the value of {@link MskServerlessClusterClientAuthentication#getSasl}
         * @param sasl sasl block. This parameter is required.
         *             Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/msk_serverless_cluster#sasl MskServerlessCluster#sasl}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder sasl(com.hashicorp.cdktf.providers.aws.msk_serverless_cluster.MskServerlessClusterClientAuthenticationSasl sasl) {
            this.sasl = sasl;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MskServerlessClusterClientAuthentication}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public MskServerlessClusterClientAuthentication build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link MskServerlessClusterClientAuthentication}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MskServerlessClusterClientAuthentication {
        private final com.hashicorp.cdktf.providers.aws.msk_serverless_cluster.MskServerlessClusterClientAuthenticationSasl sasl;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.sasl = software.amazon.jsii.Kernel.get(this, "sasl", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.msk_serverless_cluster.MskServerlessClusterClientAuthenticationSasl.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.sasl = java.util.Objects.requireNonNull(builder.sasl, "sasl is required");
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.msk_serverless_cluster.MskServerlessClusterClientAuthenticationSasl getSasl() {
            return this.sasl;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("sasl", om.valueToTree(this.getSasl()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.mskServerlessCluster.MskServerlessClusterClientAuthentication"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MskServerlessClusterClientAuthentication.Jsii$Proxy that = (MskServerlessClusterClientAuthentication.Jsii$Proxy) o;

            return this.sasl.equals(that.sasl);
        }

        @Override
        public final int hashCode() {
            int result = this.sasl.hashCode();
            return result;
        }
    }
}
